/* Main.java -- implement sun.rmi.rmic.Main
   Copyright (C) 2004, 2005, 2006, 2007  Red Hat

This file is part of java-gcj-compat.

java-gcj-compat is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

java-gcj-compat is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with java-gcj-compat; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package sun.rmi.rmic;

import java.io.*;
import java.net.*;
import java.lang.reflect.*;

public class Main
{
  static Class klass = null;
  static Method rmicMethod = null;

  static
  {
    String classname = "gnu.classpath.tools.rmic.Main";
    try
      {
        klass = Class.forName (classname);
      }
    catch (ClassNotFoundException e)
      {
        File jar = new File ("/usr/share/java/libgcj-tools-4.1.1.jar");
        if (!jar.exists () || !jar.canRead ())
          {
            System.err.println ("java-gcj-compat: tools.jar: failed to read "
                                + "/usr/share/java/libgcj-tools-4.1.1.jar");
          }

        ClassLoader loader = null;
        try
          {
            loader = new URLClassLoader(new URL[] {jar.toURL ()});
          }
        catch (MalformedURLException f)
          {
            System.err.println ("java-gcj-compat: tools.jar: malformed URL for "
                                + "/usr/share/java/libgcj-tools-4.1.1.jar");
            f.printStackTrace();
          }

        try
          {
            klass = loader.loadClass (classname);
          }
        catch (ClassNotFoundException g)
          {
            System.err.println ("java-gcj-compat: tools.jar: failed to load "
                                + classname);
            g.printStackTrace();
          }
      }

    try
      {
        rmicMethod = klass.getMethod ("main", new Class[] {String[].class});
      }
    catch (NoSuchMethodException i)
      {
        System.err.println ("java-gcj-compat: tools.jar: failed to find"
                            + " rmic main method");
        i.printStackTrace();
      }
  }

  // Ant calls this. What to do with stream and string?
  public Main (OutputStream stream, String string) {}

  public boolean compile (String[] args)
  {
    try
      {
        Object rmicInstance = klass.newInstance ();
        rmicMethod.invoke (rmicInstance, new Object[] { args });
      }
    catch (Exception e)
      {
        System.err.println ("java-gcj-compat: tools.jar: failed to run"
                            + " rmic main method");
        e.printStackTrace();
      }
    return true;
  }
}
